/** login.css **/
.login{background:#ffffff;}
.num2{color: black; font: normal 9pt Arial, Helvetica, sans-serif,ËÎÌå;width:120px;}
.button3 {
    border-top: #009900 1px solid; 
	border-left:#009900 1px solid; 
	border-bottom: #009900 1px solid; 	
	border-right: #009900 1px solid;
    background: #0099cc;
    margin: 0px;
    color: #ffffff;
	cursor:pointer;
	text-align:center;
    display:inline-block;
   /* -moz-display:inline-block;*/
    font-family:"ËÎÌå",Verdana;*font-family:"ËÎÌå",Georgia;_font-family:Tahoma;
    padding:0 10px 1px;*padding:3px 3px 1px;_padding:0 4px 1px;
    line-height:18px;*line-height:14px;_line-height:16px;
    vertical-align:middle;
    height:23px;font-size:12px;width:70px;
}  

.kuangjiang0{
width:730px;
height:450px;
margin:70px auto 0 auto;
}

.kuangjiang-mild0{
width:720px;
height:90px;
float:left;
background-color:#EEEEEE;
overflow:hidden;
}

.kuangjiang-mild-right0{
width:227px;
height:57px;
margin:15px 10px 10px 10px;
background-repeat:no-repeat;
overflow:hidden;
float:right;
}

.wangguan0{
width:400px;
height:100px;
font-size:12px;
padding:20px;
margin: 20PX 0 0 220PX;
border: #E7E7E7  0px  solid;
}

.remember{font-size:10px;    font-family:ËÎÌå, Arial, Helvetica, sans-serif;}

#loading {
       width: 300px;
       height: 120px;
       background-color: #bfebff;
       position: absolute;
       left: 60%;
       top: 50%;
       margin-top: -150px;
       margin-left: -250px;
       text-align: center;
	   background:url(../images/wait_bg.gif);
}

#bgDiv{
	width:1024px;
	height:1250px;
	position:absolute;
	top:0px; 
	left:0px; 
	background:#ffffff; 
	opacity:0.1;
	filter:alpha(opacity=10); 
	z-index:1000;
	}

form{margin:0;}

.all_body {
	width:1024px; 
	margin:0 auto; 
	padding: 0; 
	background:#fff;
	color:#333;
	/*text-align: center;*/
	position:relative;
	box-shadow: 1px 1px 8px #898989;
	}

.iframe_div{
	/*float:left;*/
	/*width:758px;*/
	width: 1024px;
	margin-left:0;
	}
	
.iframe_div1{
	/*float:left;
	width:757px;*/
	width: 1024px;
	margin-left:0;
	}
	
#iframepage{
	background:#FAFAFA;
	}

body,td,th,button,p,div,textarea,select,input {
    font-family:ËÎÌå, Arial, Helvetica, sans-serif;
	font-size:12px;
	color:#333;}
.textarea{width:640px;height:300px;}

/*top logo style*/
#top{
/*	background:url(../images/logoDAWU1023v1.png);*/
	height:66px;
	text-align:center;
	width:1024px;
	border-right:1px solid #ec9523;
	}
	
.topTable{width:100%;}

#idLanguageOption{
	background:#dcdcdc;
	border:1px solid #ffffff;
	border-radius:4px;
	}

/*content style start*/
.clear{
	clear:both;
	*height:1px;
	*margin-top:-1px;
	*overflow:hidden;
	}

.content{
	width:1024px; 
	margin:0 auto;
	border-right:1px solid #cfcfcf;
	/*background: #1E90FF;*/
	background-color: #e4e4e4;
	position:relative;
	}

.content .left{
	float:left; 
	/*width:200px; */
	text-align:left;
	width: 100%;
	padding-left: 30px;
  position: relative;
/*  text-align: left;*/
  top: -40px;
	}



.contentbody{
	width:758px;
	margin:0;
	padding:0;
	position:static;
	background-color:transparent;
	}
		
/*menu style start*/
    .left_menu1{ font-family:ËÎÌå, Arial, Helvetica, sans-serif; font-size:12px; color:#f08300;  font-weight:bold; }
    .left_menu{     font-family:ËÎÌå, Arial, Helvetica, sans-serif; font-size:12px;  color:#f08300;  font-weight:bold;text-decoration:underline; margin-left:10px; margin-right:10px}
    .left_menu:hover {    font-family:ËÎÌå, Arial, Helvetica, sans-serif; font-size:12px;  color: #FFFFFF; font-weight:bold; text-decoration:underline;cursor:pointer}
	.left img{margin:0 1px 0 1px;}

	.left ul {
		margin:0;
		padding:0;
		float: left;
		/*background-color: #fff;
		border: 1px solid red;*/
		/*border-bottom: 0px;*/
		
		position: relative;
		width: 150px;
		/*border-radius: 5px;*/
		/*border-radius-left:5px;
		border-radius-right:5px;
		-moz-border-radius-left:5px;
		-moz-border-radius-right:5px;
		-webkit-border-radius-left:5px;
		-webkit-border-radius-right:5px;*/
		background: url(../images/normal2.png) no-repeat scroll 0 0;
		margin-right: 1px;
		list-style:none}

	.left ul.current{
		background: url(../images/normal1.png) no-repeat scroll 0 0;
	}
		
	.left li{
		display:block;
		margin:0; 
		color:#FFFFFF;
		font-family:ËÎÌå, Arial, Helvetica, sans-serif;
		font-size:12px;
		padding:3px 0 3px 10px;
		cursor:pointer;
		text-decoration:none;
		text-align:left;
		/*background:#299fd8;*/
		height:20px;
		}

	.left li.current{
		/*background-color: #fe5e01;*/
	}

	.left li img{
		margin-right: 10px;
		margin-left: 10px;
	}
		
	.model{
		font-size:12px;
		font-family:"ËÎÌå", Arial, Helvetica, sans-serif;
		color:#f08300;
		padding:5px 0 5px 22px;
		}

	.left dl{
		border:solid #fff;
		border-width:0;
		margin:0;
		padding:0px;
		list-style:none;
		line-height:40px;
		/*color:#FFFFFF;*/
		position: absolute;
		top:41px;
		left:30px;

		}

	.left dl#sb1{

	}

	.left dl#sb2{
		left:180px;
	}

	.left dl#sb3{
		left:330px;
	}

	.hidden{
		display: none;
	}
		
	.left dd{
		color: #111;
		margin:0;
		padding:2px 0 2px 0px;
		font-family:ËÎÌå, Arial, Helvetica, sans-serif;
		font-size:12px;
		text-align:center;
		cursor:pointer;
		float: left;
		width:100px;
		border-left:1px solid #a1a1a1;
		border-right:1px solid #a1a1a1; 
		}

	.left dd.current{
		color: #fff;
		background-color: #fe6102;
		border-right:1px solid #fe6102; 
	}

	.left .ddbak{
		background:#2C5EA4;
		}
/*menu style end*/
.right{
	display:none;
	float:right;
	width:170px;
	text-align:left;
	line-height:22px;
	word-break:break-all;word-wrap:break-word;
	}
	
.mainbiao{
		color:#636d81;
		font-family:"ËÎÌå", Arial, Helvetica, sans-serif;
		font-size:14px;
		/*font-weight:bold;*/
		padding:20px 0 8px 0;
		}
.mainbiao1{
		padding:3px 0 8px 0;
		margin-bottom:10px;
		font-size:12px;
		font-family:"ËÎÌå", Arial, Helvetica, sans-serif;}

.contentTable {border-collapse:collapse;height:70%;text-align:center;}

.contentTable td.center{width:740px; text-align:left;padding:5px 5px 5px 16px;}
.contentTable td.center1{width:740px; text-align:left;padding:0px 5px 5px 30px;}
.contentTable td.right{width:170px;line-height:22px;background:#CCCCCC;text-align:left;}
.table01 {border-collapse:collapse;width:90%;}
.table01 td{border-width:1px; 
	border-style:solid; 
	border-color:#cccccc; 
	padding:3px 3px 3px 8px;
	height:20px;  	
	}
.table01 .leftnone{
	border-left:none;
	}
.table01 .rightnone{
	border-right:none;
	}
.table01 .topnone{
	border-top:none;
	}
.table01 .none{
	border-left:none;
	border-right:none;
	}
.table01 td.lable{background:#e9ebf1;font-weight:bold;text-align:left; height:21px;}

/*help style start*/
#showhelp{
	position:absolute;
	left:741px;
	top:8px;
	z-index:2000;
	cursor:pointer;
	}
/*help style end*/
.footer{
	height:33px;
	line-height:33px;
	width:1024px;
	background:#fff;
    font-family:ËÎÌå, Arial, Helvetica, sans-serif;
    font-size:10px;
    text-align: center;
	}
	
#version{
	height:30px;
	width:200px;
	font-family:ËÎÌå, Arial, Helvetica, sans-serif;
	font-size:10px;
	font-style:italic;
	color:#ffffff;
	text-align:center;
	position:absolute;
	left:0;
	margin-top:-40px;
	}
	
#helpline{
	position:absolute;
	}

input{ 
    height:18px;  
}
input[type=text]{ 
    height:16px;  
}
input[type=password]{ 
    height:16px;  
}
select{ 
    height:23px;  
}
input[type=radio]{ 
    height:0px;  
	height:20px !important;
	padding:0;
	vertical-align:middle;
}
input[type=checkbox]{ 
    height:0px; 
	height:12px !important; 
}

/**************** add by ycf ******************/
div#basicMenu ul{

}

div.page_content_cnt{
	text-align: center;
	margin: 0px auto;
	width: 960px;
}

div.realtime_lock{
	width: 240px;
	float: left;
}