body,p{
	margin: 0;
	padding: 0;
	font-size: 14px;
}
ul,li{
	margin: 0;
	padding: 0;
	list-style: none;
}
input{
	outline: none;
	border:none;
	border-radius: 5px;
	margin-right: 8px;
	padding-left: 5px;
}
input.current{
        width:28px;
        height: 28px;
        text-align: center;
        border: 1px solid #aaa;
        margin: 0px 5px;
        vertical-align: middle;
    }


    div.btn-part{
       /* margin-top: 20px;
        margin-bottom: 10px;*/
    }

    div.left{
        float: left;
       /* margin: 0px;*/
    }

    div.right{
        float: right;
        /*margin: 0px;*/
    }


#massage_text{
	/*height:30px;*/
	color:red;
	font-size:12px;
	text-align: center;
}
.js-dynamic,.js-static,.js-adsl{
	display: none;
}
.conn.hide{
	display: none;
}

div.login-cnt{
	box-shadow: 1px 1px 8px #898989;
	margin: 0 auto;
	width: 1024px;
}
.header{
	background: url('../images/headbg.png') center no-repeat;
	margin: 0 auto;
	width: 1024px;
	height: 130px;
	display: block;

}
.header_login{
	background: url('../images/loginhead.png') center no-repeat;
	height: 100px;
}
.login_body{
	background: url('../images/login_body.png') center no-repeat;
	height: 574px;
	width: 1024px;
	margin: 0px auto 0;
	position: relative;
	/*border: 1px solid #eee;*/
	/*box-shadow: 1px 1px 8px #898989;*/
}
.loginbox{
	width: 364px;
	height: 284px;
	background:url('../images/loginbox.png') center no-repeat;
	margin: 0 auto;
	padding-top: 189px;
	position: relative;
}
.loginbox .loginform{
	width: 220px;
	height: 400px;
	margin: 0 auto;
}
.loginbox .loginline{
	height: 30px;
	border: 1px solid #d6d6d6;
	border-radius: 5px;
	background-color: #fff;
	margin-bottom: 10px;
	vertical-align: center;
}
.loginbox .loginline i{
	width: 10px;
	height: 30px;
	position: relative;
	display: inline-block;
	vertical-align: center;
	margin-left: 10px;
}

table.body th, table.body td {
    border-right: 1px solid #c2c2c2;
}

.username i{
	background: url('../images/user.png') center center no-repeat;
}
.password i{
	background: url('../images/pwd.png') center center no-repeat;
}
.loginbox .loginline input{
	height: 27px;
	line-height: 27px;
	vertical-align: top;
	margin-left: 3px;
}
.loginbox .loginform .submit{
	background: url('../images/login.png');
	height: 30px;
	width: 220px;
	text-align: center;
	line-height: 30px;
	color: #fff;
	letter-spacing: 3px;
	cursor: pointer;
}
.loginbox .loginform .submit:hover{
	background: url('../images/login-hover.png');
}
.loginbox .loginform .submit:active{
	background: url('../images/login-click.png');
}
.logo{
	height: 40px;
	width: 950px;
	padding:24px 44px 26px 30px;
	display: inline-block;
}
.exit{
	display: inline-block;
	width: 83px;
	height: 30px;
	background-color: #fff;
	float: right;
	border-radius: 6px;
	border: 1px solid #d5d5d5;
	margin-top: 6px;
	line-height: 32px;
	text-align: center;
	color:#359fd6;
	cursor: pointer;
}
.exit a{
	color:#359fd6;
	text-decoration: none;
}
.exit img{
	vertical-align: sub;
	margin-right: 3px;
}

div.contain div.tab{
	margin:0px auto;
	margin-top: 20px;
}

.tab{
	width: 604px;
	height: 40px;
	padding-left: 30px;
	color: #fff;
}
.tab a{
	color: #fff;

}
.tab li{
	background: url('../images/normal2.png');
	height:40px;
	width: 150px;
	list-style: none;
	float: left;
	margin-right: 1px;
	line-height: 40px;
	text-align: center;
	cursor: pointer;
}
.tab li.current{
	background: url('../images/normal1.png');
}
.tab li>img{
	vertical-align: middle;
	margin-right: 10px;
}
.tab li>span{
	vertical-align: middle;
}


.contain{
	/*padding: 28px 32px 0px 30px;*/
	width: 1024px;
	margin: 0 auto;
}
.contain .sec{
	border: 1px solid #dadada;
	margin:28px 32px 0px 30px;
	/*padding-bottom: 10px;*/
}

.contain .table{
	border: 0px solid #dadada;
}
.contain .sec .title{
	height: 27px;
	line-height: 27px;
	background-color:#f2f2f2;
	color: #666666;
	/*padding-left: 20px;
	text-align: left;*/
	text-align: center;
}
.content{
	/*margin: 22px 0px 42px 44px;*/
}

div.sec .content{
	margin: 22px 0px 42px 44px;
}

.content ul li{
	line-height: 38px;
	/*line-height: normal\9;*/
	height: 40px;
	padding-left: 16px;
	/*position: relative;*/
	text-align: left;
	vertical-align: middle;
}

.content ul li.spec{
	line-height: normal\9;
}

.content ul.csf_ul li.csf_li{	
	padding-left: 0px;
}
.content ul li.necessary{
	background: url('../images/dot.png') no-repeat left center;
}
.content ul li .addr{
	background: url('../images/addr.png') center center no-repeat;
	width: 280px;
}
.content ul li .addr input{
	border:none;
	width: 50px;
	height: 20px;
	margin: 0 7px;
	text-align: center;
	line-height: 20px;
}
.content ul li .addr input:first-child{
	margin-left: 9px;
}


.content ul li span{
	display: inline-block;
	line-height: 38px;
	height: 38px;
	margin-right: 20px;
	/*vertical-align: top;*/
}
.content ul li span.explain{
	font-size: 14px;
	color: #999999;
	vertical-align:top;
}
.content ul li span.name{
	width: 130px;
}
.content ul li span.names{
	width: 145px;
}
.content ul li span.long{
	/*width: auto;*/
	vertical-align: top;
}

.contain div.mt20{
margin-top: 58px;
}

.content ul li span.conn a{
	display: inline-block;
	width: 24px;
	height: 23px;
	cursor: default;
	vertical-align: middle;
	margin-right: 10px;
}
.content ul li span.inConnect a{
	background: url('../images/connect.png')
}
.content ul li span.noConnect a{
	background: url('../images/noConnect.png')
}
.contain .content ul li span a.radio{
	display: inline-block;
	width: 14px;
	height: 14px;
	background: url('../images/radio.png');
	vertical-align:text-bottom;
	margin-right: 5px;
}
.contain .content ul li span a.radio:hover{
	background: url('../images/radio_h.png')
}
.contain .content ul li span a.radio.checked{
	background: url('../images/radio_check.png')
}
.contain .content ul li .text{
	height: 30px;
	line-height: 30px;
	width: 200px;
	border:1px solid #888888;
}
.contain  .switch{
	background: url('../images/switch_close.png') center center no-repeat;
	width: 60px;
	height: 30px;
	margin: 0 auto;
	display: inline-block;
	vertical-align: middle;
}

.contain .switch-open{
	background: url('../images/switch_open.png') center center no-repeat;
}
.contain .operate{
	margin:28px 32px 0px 30px;
}
.contain .operate a{
	float: right;
	right: 40px;
	position: relative;
	background: url('../images/6button-normal.png');
	width: 93px;
	height: 30px;
	margin-right: 20px;
	text-align: center;
	color: #fff;
	text-decoration: none;
	line-height: 30px;
	font-size: 14px;
}
.contain .operate a:hover{
	background: url('../images/6button-hover.png');
}
.contain .oneKeyLimit{
	width: 960px;
	border:1px solid #dadada;
	margin-left: 30px;
	height: 50px;
	border-width: 0px 1px 1px 1px;
}
.contain .oneKeyLimit a{
	height: 30px;
	width: 93px;
	background: url('../images/button.png');
	display: inline-block;
	text-decoration: none;
	line-height: 30px;
	float: right;
	margin: 10px 15px 0px 0px;
	text-align: center;
	color:#fff;
}
.contain .oneKeyLimit a:hover{
	background: url('../images/button-hover.png');
}
.contain .oneKeyLimit a:active{
	background: url('../images/button-click.png');
}
.contain .control{
	margin:28px 32px 0px 30px;
}
.contain .control table{
	width: 962px;
	border-collapse: collapse;
	border:1px solid #dadada;
	border-width:1px 0px 0px 1px;
}
.contain table th{
	color:#666666;
	height: 27px;
	background-color: #f2f2f2;

}
.contain .control table td{
	height: 44px;
	padding: 19px 0px;
	border-width:0px 1px 1px 0px;

}
.contain .control table td, .contain .control table th{
	border:1px solid #dadada;

	padding-left: 20px;
	text-align: left;
}

table td .host_pic{
	display: inline-block;
	width: 46px;
	height: 42px;
	background: url('../images/host.png');
}
table td .host_t{
	display: inline-block;
	vertical-align: text-bottom;
}
table td .host_t p{
	height: 20px;
	line-height: 20px;
}

table td .remark{
	height: 24px;
	width: 112px;
	border:1px solid #888888;
}
table td .limit,.line .protocol .limit{
	height: 30px;
	width: 182px;
	border: 1px solid #888888;
	border-radius: 5px;
}
table td .limit .sel_btn{
	float: right;
	width: 38px;
	height: 30px;
	background: url('../images/sel.png');
	cursor: pointer;
}
table td .limit .sel_btn:hover{
	background: url('../images/sel-hover.png');
}
table td .limit .sel_btn:active{
	background: url('../images/sel-click.png');
}
table td .limit .sel_txt{
	height: 30px;
	line-height: 30px;
	padding-left: 15px;
}
ul.selectBox{
	border: 1px  solid #888888;
	border-width: 1px 1px 0px 1px;
	position: absolute;
	width: 182px;
	z-index: 10000;
	display: none;
}
ul.selectBox.show{
	display: block;
}
.control table td ul li{
	height: 25px;
	line-height: 25px;
	border-bottom: 1px  solid #888888;
	padding-left: 15px;
}
.control table td ul li:hover{
	background-color: #999999;
}
.yellow{
	color: #fe5e03;
}
.grey{
	color: #999999;
}
.contain .repeater{
	width: 962px;
	padding:28px 32px 0px 30px;
}
.repeater .fline{
	width: 100%;
	margin:20px auto 10px;
}
.repeater .fline .title{
	display: inline-block;
	margin-right: 15px;
}
.repeater .fline .text{
	border:1px solid #888888;
	height: 24px;
	width: 200px;
	padding-left: 4px;
}
.repeater .dot{
	display: inline-block;
	margin-right: 5px;
	width: 6px;
	height: 6px;
	background: url('../images/dot.png') no-repeat left center;
}
.repeater .switch,
.repeater input[type='text']{
	margin-right: 35px;
}
.repeater .frush{
	width: 18px;
	height: 20px;
	display: inline-block;
	background: url('../images/frush.png');
	vertical-align: middle;
}
.repeater table{
	width: 962px;
	border-collapse: collapse;
	border:1px solid #dadada;
}
.repeater table a.radio{
	display: inline-block;
	width: 14px;
	height: 14px;
	background: url('../images/radio.png');
	vertical-align:text-bottom;
	margin-right: 5px;
}
.repeater table a.radio.checked{
	background: url('../images/radio_check.png');
}
.repeater table td .signal{
	width: 18px;
	height: 16px;
	display: inline-block;
}
.repeater table td .s1{
	background: url('../images/1.png');
}
.repeater table td .s2{
	background: url('../images/2.png');
}
.repeater table td .s3{
	background: url('../images/3.png');
}
.repeater table td .s4{
	background: url('../images/4.png');
}
.repeater table td .s5{
	background: url('../images/5.png');
}

.repeater table td,th{
	text-align: center;
}
.repeater table th{
	border:1px solid #dadada;;
	border-width: 0px 1px 0px 0px;
	background-color: #f2f2f2;
	height: 27px;
	color: #666666;
}
.repeater table td{
	border:1px solid #dadada;;
	border-width: 0px 1px 1px 0px;
	height: 40px;
}
/*config.html*/
.config .content{
	margin:22px 32px 42px 32px
}
.config .content table th{
	background-color: #fff;
	color: #999999;
	height: 35px;
	border-bottom: 1px solid #f2f2f2;
}
.config .content table{
	width: 100%;
	border-collapse: collapse;
}
.config .content table td{
	text-align: center;
	height: 40px;
}

.config .content table td.port{
	background: url('../images/region.png') no-repeat center center;
}
.config .content table td.port input{
	width: 70px;
	height: 24px;
	line-height: 24px;
	text-align: center;
}
.config .content table td.port input.start{
	margin-right: 15px;
}
.config .content table td input.innerIP{
	width: 30px;
	height: 26px;
	border: 2px solid #888888;
	border-width: 2px 1px 1px 1px;
	border-radius: 5px;
	text-align: center;
}
.config .content table td .protocol{
	height: 30px;
	width: 110px;
	border: 1px solid #888888;
	border-radius: 5px;
	margin: 0 auto;
}
.config .content table td .protocol .sel_btn{
	background: url('../images/sel.png');
	float: right;
	width: 38px;
	height: 30px;
	cursor: pointer;
}
.config .content table td .protocol .sel_btn:hover{
	background: url('../images/sel-hover.png');
}
.config .content table td .protocol .sel_btn:active{
	background: url('../images/sel-click.png');
}
.config .content table td .protocol .sel_txt{
	height: 30px;
	line-height: 30px;
}
.config .use,.config .del{
	width: 14px;
	height: 14px;
	display: inline-block;
	background: url('../images/uncheck.png');
}
.config .use.check:hover,.config .del.check:hover{
	background: url('../images/check-hover.png');
}
.config .use.check,.config .del.check{
	background: url('../images/check.png');
}
.config .use:hover,.config .del:hover{
	background: url('../images/uncheck-hover.png');
}
.content .line .name{
	background: url('../images/dot.png') no-repeat left center;
	height: 40px;
	line-height: 38px;
	width: 200px;
	display: inline-block;
	padding-left: 16px;
}
.content .line .protocol{
	display: inline-block;
}
.line .protocol .limit .sel_txt{
	height: 30px;
	line-height: 30px;
	padding-left: 15px;
}
.line .protocol .limit .sel_btn{
	float: right;
	width: 38px;
	height: 30px;
	background: url('../images/sel.png');
	cursor: pointer;
}
.wan .line{
	height: 45px;
}
.eqmanage .line .protocol a{
	text-decoration: none;
	color: #fff;
	text-align: center;
	background: url('../images/button.png');
	display: inline-block;
	width: 93px;
	height: 30px;
	line-height: 30px;
}


/***********************add by ycf****************************/
div.header #product-log{
	background: url("../images/logo.png") no-repeat scroll left center;
	color: #fff;
	height:40px;
	padding: 12px 0px 12px 20px;
	width:230px;
	display: inline-block;
	margin-left: 30px;
}

div#top-product-info{
	/*display: inline-block;*/
	float: right;
	right:20px;
	margin-top: 25px;
	margin-right: 20px;
}


div#top-product-info span.product-val{
	color: #f26521;
}

div.login-submit{
	width:100%;
}

div.button-container button.btn-login-submit{
	margin-top: 10px;
	width:100%;
}

.sec ul li span a.radio {
    background: url("../images/radio.png") repeat scroll 0 0;
    display: inline-block;
    height: 14px;
    margin-right: 5px;
    vertical-align: text-bottom;
    width: 14px;
}
.sec ul li span a.radio:hover {
    background:url("../images/radio_h.png") repeat scroll 0 0;
}
.sec ul li span a.radio.checked {
    background:url("../images/radio_check.png") repeat scroll 0 0;
}


.sec table tr td span a.radio {
    background: url("../images/radio.png") repeat scroll 0 0;
    display: inline-block;
    height: 14px;
    margin-right: 5px;
    vertical-align: text-bottom;
    width: 14px;
}
.sec table tr td span a.radio:hover {
    background: url("../images/radio_h.png") repeat scroll 0 0;
}
.sec table tr td span a.radio.checked {
    background: url("../images/radio_check.png") repeat scroll 0 0;
}

div.outter{
	margin-top:30px;
	margin-right: 30px;
}


#shuakasetting li{
	text-align: left;
	padding-left:35px;
}

#shuakasetting tr td{
	padding-left:35px;
}


#shuakasetting li span.shuakacishu{
	/*margin-left: 30px;*/
}

.hidden{
	display: none;
}

table tr{
	height: 32px;
	line-height: 32px;
	vertical-align: middle;
}


div.ml30{
	margin-left: 30px;s
}