#!/bin/sh -e
#cd /home/dawu
#insmod /home/dawu/hid-multitouch.ko
export QT_ROOT=/home/qt5
export LD_LIBRARY_PATH=$QT_ROOT/lib:$LD_LIBRARY_PATH
export QT_QPA_PLATFORM=linuxfb:fb=/dev/fb0:size=1280x720:mmSize=1280x720:offset=0x0:tty=/dev/tty1
#export QT_QPA_PLATFORM=linuxfb:fb=/dev/fb0:size=1024x600:mmSize=1024x600:offset=0x0:tty=/dev/tty1
export QT_QPA_FONTDIR=/usr/share/fonts
export QT_QPA_PLATFORM_PLUGIN_PATH=$QT_ROOT/plugins
export LANG=zh_CN.UTF-8
export LANGUAGE=zh_CN.UTF-8
export LC_ALL=zh_CN.UTF-8
#export TSDEVICE=/dev/input/event2 
#export QT_QPA_GENERIC_PLUGINS=evdevtouch:$TSDEVICE
#export QT_QPA_EVDEV_MOUSE_PARAMETERS=evdevtouch:/dev/input/event2  
#export QWS_MOUSE_PROTO=evdevtouch:$TSDEVICE
#export QT_QPA_EVDEV_MOUSE_PARAMETERS=Intellimouse:/dev/input/event2
#export QT_QPA_GENERIC_PLUGINS=evdevtouch:$TSDEVICE  
#export QWS_MOUSE_PROTO=evdevtouch:$TSDEVICE  
#export set QWS_DISPLAY=LinuxFb:/dev/fb0  
#export set QWS_SIZE=1024x600  
#export set QT_QWS_FONTDIR=$QTDIR/lib/fonts/
/home/dawu/dwshow&

