/* ´úÂëÕûÀí£ºÀÁÈËÖ®¼Ò lanrenzhijia.com */
html, body, div, span, applet, object, iframe, h1, h2, h3, h4, h5, h6, p, blockquote, pre, a, abbr, acronym, address, big, cite, code, del, dfn, em, font, img, ins, kbd, q, s, samp, small, strike, strong, sub, sup, tt, var, dl, dt, dd, ol, ul, li, fieldset, form, label, legend {
	margin: 0;
	padding: 0;
	border: 0;
	outline: 0;
	font-weight: inherit;
	font-style: inherit;
	font-size: 100%;
	font-family: inherit;
	vertical-align: baseline;
}
:focus {
	outline: 0;
}
body {
	line-height: 1;
	color: black;
	background: white;
}
ol, ul {
	list-style: none;
}
table {
	border-collapse: separate;
	border-spacing: 0;
}
caption, th, td {
	/*text-align: left;*/
	font-weight: normal;
}
blockquote:before, blockquote:after, q:before, q:after {
	content: "";
}
blockquote, q {
	quotes: "" "";
}
#wrap {
	width:830px;
	margin:15px auto;
}
hr {
	margin:20px 10px;
	background-color:#CCC;
}
/*
*********************************************
***************** DEMO 01 *******************
*********************************************
ID Container = div.csf0

*/


/* --- Fake Input Div --- */
div.csf0 div.csf_input {
	width:130px;
	height:18px;
	border:1px solid #00aeff;
}
div.csf0 div.csf_input p {
	/*display:inline;*/
	color:#0572a5;
	height:18px;
}
div.csf0 div.csf_input span.itemSelected {
	margin-left:3px;
	margin-right:8px;
	height:18px;
	text-align:left;
}
/* --- Button --- */ 
div.csf0 a.csf_btn {
	float:right;
	display:inline-block;
	height:18px;
	text-align:right;
	width:18px;
*margin-top: -16px;
}
/* --- Open Button --- */ 
div.csf0 a.csf_btn:link, div.csf0 a.csf_btn:visited, div.csf0 a.csf_btn:active {
	background-image:url(../images/demo01/btn18.jpg);
	background-position:0 0;
}
div.csf0 a.csf_btn:hover {
	background-image:url(../images/demo01/btn18.jpg);
	background-position:-18px 0;
}
/* --- Close Button --- */ 
div.csf0 a.csf_btn.opened:link, div.csf0 a.csf_btn.opened:visited, div.csf0 a.csf_btn.opened:active {
	background-image:url(../images/demo01/btn18.jpg);
	background-position:0 -18px;
}
div.csf0 a.csf_btn.opened:hover {
	background-image:url(../images/demo01/btn18.jpg);
	background-position:-18px -18px;
}
/* --- List items --- */
div.csf0 ul.csf_ul {
	position:absolute!important;
	width:130px;
	border:1px solid #00aeff;
	border-top:0px solid #000;
	z-index:250;
}
div.csf0 li.csf_li {
	background-color:#FFF;
	z-index: 250px;
}
div.csf0 li.csf_li a {
	display:block;
	width:124px;
	height:18px;
	color:#00aeff;
	padding:3px;
	text-decoration:none;
	background-color:#FFF;
	color:#00aeff;
}
div.csf0 li.csf_li a:link, div.csf0 li.csf_li a:visited, div.csf0 li.csf_li a:active {
}
div.csf0 li.csf_li a:hover {
	background-color:#00aeff;
	color:#FFF;
}
div.csf0 img.iconCSF {
	vertical-align:middle;
	margin-bottom:2px;
}
div.csf0 li.selected a {
	display:block;
	height:18px;
	background-color:#0572a5;
	color:#FFF;
	padding:3px;
	text-decoration:none;
}
/*
*********************************************
***************** DEMO 02 *******************
*********************************************
ID Container = div.customSelect

*/

/* --- Fake Input Div --- */
div.customSelect div.csf_input {
	width:200px;
	height:30px;
	/*height:22px\9;*/
	/*background-image:url(../images/bgDivClass.png);*/
	border: 1px solid #aaa;
	border-radius: 3px;
	background-repeat:no-repeat;
	margin-right: 8px;

}
div.customSelect div.csf_input p {
	display:inline;
	color:#5b3444;
	height:30px;
	height:22px\9;
}
div.customSelect div.csf_input span.itemSelected {
	position:relative;
	top:-5px;
	margin-left:5px;
	margin-right:8px;
	text-align:left;
}

/* --- Button --- */ 
div.inline-block{
	display: inline-block;
        /*display:-moz-inline-stack;*/
        *zoom:1;
	*display:inline;
}
div.customSelect a.csf_btn {
	float:right;
	display:inline-block;
	height:30px;
	height:22px\9;
	height:32px\9;
	text-align:right;
	width:38px;
	
*margin-top: -16px;
	/*margin-top: -35px\9;*/
}
/* --- Open Button --- */ 
div.customSelect a.csf_btn:link, div.customSelect a.csf_btn:visited, div.customSelect a.csf_btn:active {
	background-image:url(../images/select-normal.png);
	background-position:0 0;
}
div.customSelect a.csf_btn:hover {
	background-image:url(../images/select-normal.png);
	/*background-position:-20px 0;*/
}
/* --- Close Button --- */ 
div.customSelect a.csf_btn.opened:link, div.customSelect a.csf_btn.opened:visited, div.customSelect a.csf_btn.opened:active {
	background-image:url(../images/select-normal.png);
	/*background-position:0 -21px;*/
}
div.customSelect a.csf_btn.opened:hover {
	background-image:url(../images/select-normal.png);
	/*background-position:-20px -21px;*/
}
/* --- List items --- */
div.customSelect ul.csf_ul {
	position:absolute!important;
	width:198px;
	border:1px solid #dddddd;
	border-top:0px solid #000;
	max-height:80px;
	overflow-y:scroll;
	overflow-x:hidden;
	z-index:250;
	box-shadow: 1px 1px 5px #898989;
}
div.customSelect li.csf_li {
	background-color:#FFF;
}
div.customSelect li.csf_li a {
	display:block;
	width:190px;
	height:27px;
	/*color:#bb4477;*/
	color:#898989;
	background-color:#FFF;
	padding:5px;
	text-decoration:none;
}
div.customSelect li.csf_li a:link, li.csf_li a:visited, li.csf_li a:active {
}
div.customSelect li.csf_li a:hover {
	/*background-color:#e68da8;*/
	background-color:#58c4dd;
	color:#FFF;
}
div.customSelect li.selected a {
	display:block;
	height:27px;
	/*background-color:#bb4477;*/
	background-color: #3296ad;
	color:#FFF;
	padding:5px;
	text-decoration:none;
}
/* ´úÂëÕûÀí£ºÀÁÈËÖ®¼Ò lanrenzhijia.com */


	

	

.ui-timepicker-div .ui-widget-header { margin-bottom: 8px; } 

.ui-timepicker-div dl { text-align: left; } 

.ui-timepicker-div dl dt { height: 25px; margin-bottom: -25px; } 

.ui-timepicker-div dl dd { margin: 0 10px 10px 65px; } 

.ui-timepicker-div td { font-size: 90%; } 

.ui-tpicker-grid-label { background: none; border: none; margin: 0; padding: 0; } 

.ui_tpicker_hour_label,.ui_tpicker_minute_label,.ui_tpicker_second_label, 

.ui_tpicker_millisec_label,.ui_tpicker_time_label{padding-left:20px} 

